@@ -3,11 +3,14 @@
 
 #include <gio/gio.h>
 
+#include "gitestmacros.h"
+
 typedef struct {
   double x;
   double y;
 } SPoint;
 
+_GI_TEST_EXTERN
 void s_hello (void);
 
 /* Like GSpawnError; not registered with GType */
@@ -17,6 +20,8 @@ typedef enum
   S_SPAWN_ERROR_CODE2 = 2,
   S_SPAWN_ERROR_CODE3 = 3
 } SSpawnError;
+
+_GI_TEST_EXTERN
 GQuark s_spawn_error_quark (void);
 
 /* Like GDBusError but not registered with GType */
@@ -26,6 +31,8 @@ typedef enum
   S_DBUS_ERROR_CODE2 = 2,
   S_DBUS_ERROR_CODE3 = 3
 } SDBusError;
+
+_GI_TEST_EXTERN
 GQuark s_dbus_error_quark (void);
 
 #endif
